==> openjdk-17_17.0.18~7ea.orig.tar.xz: openjdk-17-17.0.18~7ea/src/hotspot/share/jfr/support/jfrStackTraceMark.hpp <==
/*
 * Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_JFR_SUPPORT_JFRSTACKTRACEMARK_HPP
#define SHARE_JFR_SUPPORT_JFRSTACKTRACEMARK_HPP

#include "memory/allocation.hpp"
#include "jfrfiles/jfrEventIds.hpp"
#include "jfr/utilities/jfrTypes.hpp"

class Thread;

class JfrStackTraceMark {
 private:
  Thread* _t;
  traceid _previous_id;
  unsigned int _previous_hash;
 public:
  JfrStackTraceMark();
  JfrStackTraceMark(Thread* t);
  JfrStackTraceMark(JfrEventId eventId);
  JfrStackTraceMark(JfrEventId eventId, Thread* t);
  ~JfrStackTraceMark();
};

#endif // SHARE_JFR_SUPPORT_JFRSTACKTRACEMARK_HPP

==> openjdk-25_25~32ea.orig.tar.xz: openjdk-25-25~32ea/src/hotspot/share/jfr/support/jfrStackTraceMark.hpp <==
/*
 * Copyright (c) 2016, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_JFR_SUPPORT_JFRSTACKTRACEMARK_HPP
#define SHARE_JFR_SUPPORT_JFRSTACKTRACEMARK_HPP

#include "memory/allocation.hpp"
#include "jfrfiles/jfrEventIds.hpp"
#include "jfr/utilities/jfrTypes.hpp"

class Thread;

class JfrStackTraceMark {
 private:
  Thread* _t;
  traceid _previous_id;
  traceid _previous_hash;
 public:
  JfrStackTraceMark();
  JfrStackTraceMark(Thread* t);
  JfrStackTraceMark(JfrEventId eventId);
  JfrStackTraceMark(JfrEventId eventId, Thread* t);
  ~JfrStackTraceMark();
};

#endif // SHARE_JFR_SUPPORT_JFRSTACKTRACEMARK_HPP
